==> cms-db_v0.7.11.tar.gz: admin/login.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
if (file_exists('../data/version.txt')) {
	include('login.inc.php');
	include('escape.inc.php');
	$file = check_user_data(escapeSL($_POST['user']), escapeSL($_POST['pass']));
	if ($file !== false) {
		session_start();
		$_SESSION['CMS-Login'] = 'LOGEDIN';
		$_SESSION['CMS-User'] = $file;
		$_SESSION['CMS-SU'] = 'NONE';
		$_SESSION['CMS-Settings'] = '';
		$_SESSION['CMS-Locale'] = $_POST['locale'];
		$_SESSION['CMS-Mode'] = $_POST['mode'];
		$version_installed = file_get_contents('../data/version.txt');
		$version_available = file_get_contents('./update/version.txt');
		if ($version_installed != $version_available) {
			if (!file_exists('../data/update.tar.gz')) {
				header('Location: update/index.php?'.SID);
			} else {
				header('Location: update/incomplete.php?'.SID);
			}
		} else {
			if ($_SESSION['CMS-Mode'] != 'quirks') {
				include('mobile.inc.php');
				if (!mobile()) {
					header('Location: frame.php?'.SID);
				} else {
					header('Location: mobile.php?'.SID);
				}
			} else {
				header('Location: quirks-mode.php?'.SID);
			}
		}
		die();
	}
} else {
	session_start();
	$_SESSION['CMS-Login'] = 'LOGEDIN';
	$_SESSION['CMS-User'] = 'firstrun';
	$_SESSION['CMS-SU'] = 'NONE';
	$_SESSION['CMS-Settings'] = '';
	if (isset($_GET['locale'])) {
		$_SESSION['CMS-Locale'] = $_GET['locale'];
	} elseif (isset($_POST['locale'])) {
		$_SESSION['CMS-Locale'] = $_POST['locale'];
	} else {
		$_SESSION['CMS-Locale'] = 'en';
	}
	$_SESSION['CMS-Mode'] = 'standard';
	header('Location: firstrun.php?'.SID);
	die();
}
header('Location: index.php?special=wrongpw&locale='.$_POST['locale']);
?>

==> cms-db_v0.8.1.tar.gz: admin/login.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

require_once('csrfprotection.inc.php');

if (file_exists('../data/version.txt')) {
	require_once('login.inc.php');
	require_once('escape.inc.php');
	$file = check_user_data(escapeSL($_POST['user']), escapeSL($_POST['pass']));
	if ($file !== false) {
		session_start();
		$_SESSION['CMS-Login'] = 'LOGEDIN';
		$_SESSION['CMS-User'] = $file;
		$_SESSION['CMS-SU'] = 'NONE';
		$_SESSION['CMS-Settings'] = '';
		$_SESSION['CMS-Locale'] = $_POST['locale'];
		$_SESSION['CMS-Mode'] = $_POST['mode'];
		$_SESSION['CMS-Hash'] = md5(uniqid(mt_rand(), true));
		$version_installed = file_get_contents('../data/version.txt');
		$version_available = file_get_contents('./update/version.txt');
		if ($version_installed != $version_available) {
			if (!file_exists('../data/update.tar.gz')) {
				header('Location: update/index.php?'.SID.csrf_protection_get());
			} else {
				header('Location: update/incomplete.php?'.SID.csrf_protection_get());
			}
		} else {
			if ($_SESSION['CMS-Mode'] != 'quirks') {
				include('mobile.inc.php');
				if (mobile() or tablet()) {
					header('Location: mobile.php?'.SID.csrf_protection_get());
				} else {
					header('Location: frame.php?'.SID.csrf_protection_get());
				}
			} else {
				header('Location: quirks-mode.php?'.SID.csrf_protection_get());
			}
		}
		die();
	}
} else {
	session_start();
	$_SESSION['CMS-Login'] = 'LOGEDIN';
	$_SESSION['CMS-User'] = 'firstrun';
	$_SESSION['CMS-SU'] = 'NONE';
	$_SESSION['CMS-Settings'] = '';
	if (isset($_GET['locale'])) {
		$_SESSION['CMS-Locale'] = $_GET['locale'];
	} elseif (isset($_POST['locale'])) {
		$_SESSION['CMS-Locale'] = $_POST['locale'];
	} else {
		$_SESSION['CMS-Locale'] = 'en';
	}
	$_SESSION['CMS-Mode'] = 'standard';
	$_SESSION['CMS-Hash'] = md5(uniqid(mt_rand(), true));
	header('Location: firstrun.php?'.SID.csrf_protection_get());
	die();
}
header('Location: index.php?special=wrongpw&locale='.$_POST['locale']);
?>
